diff -urN debootstrap-0.2.28/debian/changelog debootstrap-0.2.29/debian/changelog
--- debootstrap-0.2.28/debian/changelog	2004-02-24 00:57:38.000000000 -0800
+++ debootstrap-0.2.29/debian/changelog	2004-03-10 02:29:27.920246224 -0800
@@ -1,3 +1,12 @@
+debootstrap (0.2.29) unstable; urgency=low
+
+  * NMU with permission of maintainer.
+  * Added {woody,sarge,sid}.buildd scripts to create build chroots.
+    Closes: #236418.
+  * Added --variant=buildd option for convenient access to these scripts.
+
+ -- Daniel Schepler <schepler@debian.org>  Wed, 10 Mar 2004 02:29:27 -0800
+
 debootstrap (0.2.28) unstable; urgency=medium
 
   * [sid] Exim has changed GnuTLS dependencies. Added libgnutls10, libgcrypt7,
diff -urN debootstrap-0.2.28/debian/rules debootstrap-0.2.29/debian/rules
--- debootstrap-0.2.28/debian/rules	2003-11-10 06:06:11.000000000 -0800
+++ debootstrap-0.2.29/debian/rules	2004-03-06 02:54:28.000000000 -0800
@@ -98,7 +98,8 @@
 	dh_testroot
 	-rm -rf debian/debootstrap-udeb/usr/share \
 		debian/debootstrap-udeb/usr/lib/debootstrap/scripts/slink \
-		debian/debootstrap-udeb/usr/lib/debootstrap/scripts/potato
+		debian/debootstrap-udeb/usr/lib/debootstrap/scripts/potato \
+		debian/debootstrap-udeb/usr/lib/debootstrap/scripts/*.buildd
 	dh_strip -pdebootstrap-udeb
 	dh_compress -pdebootstrap-udeb
 	dh_fixperms -pdebootstrap-udeb
diff -urN debootstrap-0.2.28/debootstrap debootstrap-0.2.29/debootstrap
--- debootstrap-0.2.28/debootstrap	2003-11-10 06:06:10.000000000 -0800
+++ debootstrap-0.2.29/debootstrap	2004-03-06 12:19:01.000000000 -0800
@@ -17,6 +17,7 @@
 GETTEXT_LANG=$LANG
 LANG=C
 USE_COMPONENTS=main
+VARIANT=""
 
 export LANG USE_COMPONENTS
 umask 022
@@ -47,6 +48,8 @@
       --verbose              don't turn off the output of wget
       --components=A,B,C     use packages from the listed components of the 
                              archive
+      --variant=X            use variant X of the bootstrap scripts
+                             (currently supported variants: buildd)
 EOF
 }
 
@@ -122,6 +125,10 @@
     export USE_COMPONENTS
     shift 1
     ;;
+  --variant*)
+    VARIANT="$(echo "$1" | cut -f2 -d"=")"
+    shift 1
+    ;;
 	*)
 	  break
 	  ;;
@@ -147,6 +154,9 @@
 
 MIRRORS="http://ftp.debian.org/debian"
 SCRIPT="$DEBOOTSTRAP_DIR/scripts/$1"
+if [ -n "$VARIANT" ]; then
+    SCRIPT="${SCRIPT}.${VARIANT}"
+fi
 if [ "$3" != "" ]; then
   MIRRORS="$3"
   if [ "$4" != "" ]; then
diff -urN debootstrap-0.2.28/debootstrap.8 debootstrap-0.2.29/debootstrap.8
--- debootstrap-0.2.28/debootstrap.8	2003-11-10 06:06:10.000000000 -0800
+++ debootstrap-0.2.29/debootstrap.8	2004-03-06 12:30:14.000000000 -0800
@@ -34,9 +34,17 @@
 .IP
 .IP "\fB--exclude=alpha,beta\fP"
 Comma separated list of packages which will be removed from download and
-extract lists. WARNING: you can and probably will exlude essential packages, be
+extract lists. WARNING: you can and probably will exclude essential packages, be
 careful using this option.
 .IP
+.IP "\fB--variant=buildd\fP"
+Name of the bootstrap script variant to use.  Currently, the only variant
+supported is buildd, which installs the build-essential packages into
+.IR TARGET .
+The default, with no \fB--variant=X\fP argument, is to create a base
+Debian installation in
+.IR TARGET .
+.IP
 .IP "\fB--verbose\fP"
 Produce more info about downloading.
 .IP
diff -urN debootstrap-0.2.28/Makefile debootstrap-0.2.29/Makefile
--- debootstrap-0.2.28/Makefile	2003-11-10 06:06:10.000000000 -0800
+++ debootstrap-0.2.29/Makefile	2004-03-06 02:13:26.000000000 -0800
@@ -27,6 +27,9 @@
 	install -o root -g root -m 0644 woody $(DSDIR)/scripts/
 	install -o root -g root -m 0644 sarge $(DSDIR)/scripts/
 	install -o root -g root -m 0644 sid $(DSDIR)/scripts/
+	install -o root -g root -m 0644 woody.buildd $(DSDIR)/scripts/
+	install -o root -g root -m 0644 sarge.buildd $(DSDIR)/scripts/
+	install -o root -g root -m 0644 sid.buildd $(DSDIR)/scripts/
 	install -o root -g root -m 0644 functions $(DSDIR)/
 	install -o root -g root -m 0755 pkgdetails $(DSDIR)/
 	install -o root -g root -m 0644 devices.tar.gz $(DSDIR)/
diff -urN debootstrap-0.2.28/sarge.buildd debootstrap-0.2.29/sarge.buildd
--- debootstrap-0.2.28/sarge.buildd	1969-12-31 16:00:00.000000000 -0800
+++ debootstrap-0.2.29/sarge.buildd	2004-03-06 02:12:11.000000000 -0800
@@ -0,0 +1,178 @@
+mirror_style release
+download_style apt
+
+work_out_debs () {
+
+    required="base-files base-passwd bash bsdutils coreutils debianutils diff dpkg dselect e2fslibs e2fsprogs findutils gcc-3.3-base grep gzip hostname initscripts libacl1 libattr1 libblkid1 libc6 libcap1 libcomerr2 libdb1-compat libdb3 libgcc1 libncurses5 libpam-modules libpam-runtime libpam0g libss2 libstdc++5 libuuid1 login mawk mount ncurses-base ncurses-bin perl-base sed slang1a-utf8 sysv-rc sysvinit tar util-linux zlib1g"
+
+    base="apt binutils cpio cpp cpp-3.3 dpkg-dev g++ g++-3.3 gcc gcc-3.3 libc6-dev libdb4.0 libgdbm3 libstdc++5-3.3-dev linux-kernel-headers make patch perl perl-modules $additional"
+
+    without_package () {
+        echo "$2" | tr ' ' '\n' | grep -v "^$1$" | tr '\n' ' '
+    }
+
+    LIBC6=libc6
+
+    case $ARCH in
+        "alpha")
+            required="$(without_package "libc6" "$required") libc6.1"
+	    base="$(without_package "libc6-dev" "$base") libc6.1-dev"
+            LIBC6="libc6.1"
+            ;;
+        "arm")
+            ;;
+        "i386")
+            ;;
+        "ia64")
+            required="$(without_package "libc6" "$required") libc6.1"
+	    base="$(without_package "libc6-dev" "$base") libc6.1-dev"
+            LIBC6="libc6.1"
+            ;;
+        "m68k")
+            ;;
+        "powerpc")
+            ;;
+        "sparc")
+            ;;
+        "mips")
+            ;;
+        "mipsel")
+            ;;
+        "hppa")
+            ;;
+        s390|s390x)
+            ;;
+	sh*)
+	    ;;
+        *)
+            # who knows?
+            ;;
+    esac
+
+    all_debs="$required $base"
+
+    for x in $exclude; do
+      all_debs="$(without_package "$x" "$all_debs")"
+    done
+    
+}
+
+install_debs () {
+    first_stage_install
+    second_stage_install
+}
+
+first_stage_install () {
+    extract $required
+
+    mkdir -p "$TARGET/var/lib/dpkg"
+    : >"$TARGET/var/lib/dpkg/status"
+    : >"$TARGET/var/lib/dpkg/available"
+
+    setup_etc
+    if [ ! -e "$TARGET/etc/fstab" ]; then
+        echo '# UNCONFIGURED FSTAB FOR BASE SYSTEM' > "$TARGET/etc/fstab"
+        chown 0.0 "$TARGET/etc/fstab"; chmod 644 "$TARGET/etc/fstab"
+    fi
+
+    setup_proc
+    setup_devices
+
+    in_target /sbin/ldconfig
+
+    p () {
+	baseprog="$(($baseprog + ${1:-1}))"
+    }
+
+    x_feign_install () {
+        local pkg="$1"
+        local deb="$(debfor $pkg)"
+        local ver="$(
+            ar -p "$TARGET/$deb" control.tar.gz | zcat |
+                tar -O -xf - control ./control 2>/dev/null |
+                sed -ne 's/^Version: *//Ip' | head -n 1
+        )"
+
+        mkdir -p "$TARGET/var/lib/dpkg/info"
+
+        echo \
+"Package: $pkg
+Version: $ver
+Status: install ok installed" >> "$TARGET/var/lib/dpkg/status"
+
+        touch "$TARGET/var/lib/dpkg/info/${pkg}.list"
+    }
+
+    x_feign_install dpkg
+}
+
+second_stage_install () {
+    x_core_install () {
+	smallyes '' | in_target dpkg --force-depends --install $(debfor "$@")
+    }
+
+    DEBIAN_FRONTEND=noninteractive
+    export DEBIAN_FRONTEND
+
+    baseprog=0
+    bases=40
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #1
+    info INSTCORE "Installing core packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #2
+    ln -s mawk $TARGET/usr/bin/awk
+    x_core_install base-files base-passwd
+    p; progress $baseprog $bases INSTBASE "Installing base system" #3
+    x_core_install dpkg
+
+    if [ ! -e "$TARGET/etc/localtime" ]; then
+        ln -sf /usr/share/zoneinfo/UTC "$TARGET/etc/localtime"
+    fi
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #4
+    x_core_install $LIBC6
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #5
+    x_core_install perl-base
+    p; progress $baseprog $bases INSTBASE "Installing base system" #6
+    rm $TARGET/usr/bin/awk
+    x_core_install mawk
+    p; progress $baseprog $bases INSTBASE "Installing base system" #7
+
+    info UNPACKREQ "Unpacking required packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #8
+    smallyes '' | repeat 5 in_target_failmsg UNPACK_REQ_FAIL_FIVE "Failure while unpacking required packages.  This will be attempted up to five times." "" dpkg --force-depends --unpack $(debfor $required)
+    p 10; progress $baseprog $bases INSTBASE "Installing base system" #18
+
+    info CONFREQ "Configuring required packages..."
+
+    mv "$TARGET/sbin/start-stop-daemon" "$TARGET/sbin/start-stop-daemon.REAL"
+    echo \
+"#!/bin/sh
+echo
+echo \"Warning: Fake start-stop-daemon called, doing nothing\"" > "$TARGET/sbin/start-stop-daemon"
+    chmod 755 "$TARGET/sbin/start-stop-daemon"
+
+    setup_dselect_method apt
+    #on_exit "in_target_nofail umount /dev/pts"
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #19
+    smallyes '' | in_target_failmsg CONF_REQ_FAIL "Failure while configuring required packages." "" dpkg --configure --pending --force-configure-any --force-depends
+    p 10; progress $baseprog $bases INSTBASE "Installing base system" #29 
+
+    info INSTBASE "Installing base packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #30
+    smallyes '' | repeat 5 in_target_failmsg INST_BASE_FAIL_FIVE "Failure while installing base packages.  This will be re-attempted up to five times." "" dpkg --force-auto-select --force-overwrite --force-confold --skip-same-version --unpack $(debfor $base)
+
+    smallyes '' | repeat 5 in_target_failmsg CONF_BASE_FAIL_FIVE "Failure while configuring base packages.  This will be attempted 5 times." "" dpkg  --force-confold --skip-same-version  --configure -a
+
+    p 9; progress $baseprog $bases INSTBASE "Installing base system" #39
+
+    mv "$TARGET/sbin/start-stop-daemon.REAL" "$TARGET/sbin/start-stop-daemon"
+
+    progress $bases $bases INSTBASE "Installing base system" #40
+    info BASESUCCESS "Base system installed successfully."
+}
diff -urN debootstrap-0.2.28/sid.buildd debootstrap-0.2.29/sid.buildd
--- debootstrap-0.2.28/sid.buildd	1969-12-31 16:00:00.000000000 -0800
+++ debootstrap-0.2.29/sid.buildd	2004-03-06 02:12:15.000000000 -0800
@@ -0,0 +1,178 @@
+mirror_style release
+download_style apt
+
+work_out_debs () {
+
+    required="base-files base-passwd bash bsdutils coreutils debianutils diff dpkg dselect e2fslibs e2fsprogs findutils gcc-3.3-base grep gzip hostname initscripts libacl1 libattr1 libblkid1 libc6 libcap1 libcomerr2 libdb1-compat libdb3 libgcc1 libncurses5 libpam-modules libpam-runtime libpam0g libss2 libstdc++5 libuuid1 login mawk mount ncurses-base ncurses-bin perl-base sed slang1a-utf8 sysv-rc sysvinit tar util-linux zlib1g"
+
+    base="apt binutils cpio cpp cpp-3.3 dpkg-dev g++ g++-3.3 gcc gcc-3.3 libc6-dev libdb4.0 libgdbm3 libstdc++5-3.3-dev linux-kernel-headers make patch perl perl-modules $additional"
+
+    without_package () {
+        echo "$2" | tr ' ' '\n' | grep -v "^$1$" | tr '\n' ' '
+    }
+
+    LIBC6=libc6
+
+    case $ARCH in
+        "alpha")
+            required="$(without_package "libc6" "$required") libc6.1"
+	    base="$(without_package "libc6-dev" "$base") libc6.1-dev"
+            LIBC6="libc6.1"
+            ;;
+        "arm")
+            ;;
+        "i386")
+            ;;
+        "ia64")
+            required="$(without_package "libc6" "$required") libc6.1"
+	    base="$(without_package "libc6-dev" "$base") libc6.1-dev"
+            LIBC6="libc6.1"
+            ;;
+        "m68k")
+            ;;
+        "powerpc")
+            ;;
+        "sparc")
+            ;;
+        "mips")
+            ;;
+        "mipsel")
+            ;;
+        "hppa")
+            ;;
+        s390|s390x)
+            ;;
+	sh*)
+	    ;;
+        *)
+            # who knows?
+            ;;
+    esac
+
+    all_debs="$required $base"
+
+    for x in $exclude; do
+      all_debs="$(without_package "$x" "$all_debs")"
+    done
+    
+}
+
+install_debs () {
+    first_stage_install
+    second_stage_install
+}
+
+first_stage_install () {
+    extract $required
+
+    mkdir -p "$TARGET/var/lib/dpkg"
+    : >"$TARGET/var/lib/dpkg/status"
+    : >"$TARGET/var/lib/dpkg/available"
+
+    setup_etc
+    if [ ! -e "$TARGET/etc/fstab" ]; then
+        echo '# UNCONFIGURED FSTAB FOR BASE SYSTEM' > "$TARGET/etc/fstab"
+        chown 0.0 "$TARGET/etc/fstab"; chmod 644 "$TARGET/etc/fstab"
+    fi
+
+    setup_proc
+    setup_devices
+
+    in_target /sbin/ldconfig
+
+    p () {
+	baseprog="$(($baseprog + ${1:-1}))"
+    }
+
+    x_feign_install () {
+        local pkg="$1"
+        local deb="$(debfor $pkg)"
+        local ver="$(
+            ar -p "$TARGET/$deb" control.tar.gz | zcat |
+                tar -O -xf - control ./control 2>/dev/null |
+                sed -ne 's/^Version: *//Ip' | head -n 1
+        )"
+
+        mkdir -p "$TARGET/var/lib/dpkg/info"
+
+        echo \
+"Package: $pkg
+Version: $ver
+Status: install ok installed" >> "$TARGET/var/lib/dpkg/status"
+
+        touch "$TARGET/var/lib/dpkg/info/${pkg}.list"
+    }
+
+    x_feign_install dpkg
+}
+
+second_stage_install () {
+    x_core_install () {
+	smallyes '' | in_target dpkg --force-depends --install $(debfor "$@")
+    }
+
+    DEBIAN_FRONTEND=noninteractive
+    export DEBIAN_FRONTEND
+
+    baseprog=0
+    bases=40
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #1
+    info INSTCORE "Installing core packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #2
+    ln -s mawk $TARGET/usr/bin/awk
+    x_core_install base-files base-passwd
+    p; progress $baseprog $bases INSTBASE "Installing base system" #3
+    x_core_install dpkg
+
+    if [ ! -e "$TARGET/etc/localtime" ]; then
+        ln -sf /usr/share/zoneinfo/UTC "$TARGET/etc/localtime"
+    fi
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #4
+    x_core_install $LIBC6
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #5
+    x_core_install perl-base
+    p; progress $baseprog $bases INSTBASE "Installing base system" #6
+    rm $TARGET/usr/bin/awk
+    x_core_install mawk
+    p; progress $baseprog $bases INSTBASE "Installing base system" #7
+
+    info UNPACKREQ "Unpacking required packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #8
+    smallyes '' | repeat 5 in_target_failmsg UNPACK_REQ_FAIL_FIVE "Failure while unpacking required packages.  This will be attempted up to five times." "" dpkg --force-depends --unpack $(debfor $required)
+    p 10; progress $baseprog $bases INSTBASE "Installing base system" #18
+
+    info CONFREQ "Configuring required packages..."
+
+    mv "$TARGET/sbin/start-stop-daemon" "$TARGET/sbin/start-stop-daemon.REAL"
+    echo \
+"#!/bin/sh
+echo
+echo \"Warning: Fake start-stop-daemon called, doing nothing\"" > "$TARGET/sbin/start-stop-daemon"
+    chmod 755 "$TARGET/sbin/start-stop-daemon"
+
+    setup_dselect_method apt
+    #on_exit "in_target_nofail umount /dev/pts"
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #19
+    smallyes '' | in_target_failmsg CONF_REQ_FAIL "Failure while configuring required packages." "" dpkg --configure --pending --force-configure-any --force-depends
+    p 10; progress $baseprog $bases INSTBASE "Installing base system" #29 
+
+    info INSTBASE "Installing base packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #30
+    smallyes '' | repeat 5 in_target_failmsg INST_BASE_FAIL_FIVE "Failure while installing base packages.  This will be re-attempted up to five times." "" dpkg --force-auto-select --force-overwrite --force-confold --skip-same-version --unpack $(debfor $base)
+
+    smallyes '' | repeat 5 in_target_failmsg CONF_BASE_FAIL_FIVE "Failure while configuring base packages.  This will be attempted 5 times." "" dpkg  --force-confold --skip-same-version  --configure -a
+
+    p 9; progress $baseprog $bases INSTBASE "Installing base system" #39
+
+    mv "$TARGET/sbin/start-stop-daemon.REAL" "$TARGET/sbin/start-stop-daemon"
+
+    progress $bases $bases INSTBASE "Installing base system" #40
+    info BASESUCCESS "Base system installed successfully."
+}
diff -urN debootstrap-0.2.28/woody.buildd debootstrap-0.2.29/woody.buildd
--- debootstrap-0.2.28/woody.buildd	1969-12-31 16:00:00.000000000 -0800
+++ debootstrap-0.2.29/woody.buildd	2004-03-06 02:12:07.000000000 -0800
@@ -0,0 +1,178 @@
+mirror_style release
+download_style apt
+
+work_out_debs () {
+
+    required="base-files base-passwd bash bsdutils debianutils diff dpkg e2fsprogs fileutils findutils grep gzip hostname libc6 libcap1 libdb3 libncurses5 libpam-modules libpam-runtime libpam0g libstdc++2.10-glibc2.2 login mawk mount ncurses-base ncurses-bin perl-base sed shellutils slang1 sysvinit tar textutils util-linux"
+
+    base="apt binutils cpio cpp cpp-2.95 debconf dpkg-dev g++ g++-2.95 gcc gcc-2.95 libc6-dev libdb2 libgdbmg1 libstdc++2.10-dev make patch perl perl-modules $additional"
+
+    without_package () {
+        echo "$2" | tr ' ' '\n' | grep -v "^$1$" | tr '\n' ' '
+    }
+
+    LIBC6=libc6
+
+    case $ARCH in
+        "alpha")
+            required="$(without_package "libc6" "$required") libc6.1"
+	    base="$(without_package "libc6-dev" "$base") libc6.1-dev"
+            LIBC6="libc6.1"
+            ;;
+        "arm")
+            ;;
+        "i386")
+            ;;
+        "ia64")
+            required="$(without_package "libc6" "$required") libc6.1"
+	    base="$(without_package "libc6-dev" "$base") libc6.1-dev"
+            LIBC6="libc6.1"
+            ;;
+        "m68k")
+            ;;
+        "powerpc")
+            ;;
+        "sparc")
+            ;;
+        "mips")
+            ;;
+        "mipsel")
+            ;;
+        "hppa")
+            ;;
+        s390|s390x)
+            ;;
+	sh*)
+	    ;;
+        *)
+            # who knows?
+            ;;
+    esac
+
+    all_debs="$required $base"
+
+    for x in $exclude; do
+      all_debs="$(without_package "$x" "$all_debs")"
+    done
+    
+}
+
+install_debs () {
+    first_stage_install
+    second_stage_install
+}
+
+first_stage_install () {
+    extract $required
+
+    mkdir -p "$TARGET/var/lib/dpkg"
+    : >"$TARGET/var/lib/dpkg/status"
+    : >"$TARGET/var/lib/dpkg/available"
+
+    setup_etc
+    if [ ! -e "$TARGET/etc/fstab" ]; then
+        echo '# UNCONFIGURED FSTAB FOR BASE SYSTEM' > "$TARGET/etc/fstab"
+        chown 0.0 "$TARGET/etc/fstab"; chmod 644 "$TARGET/etc/fstab"
+    fi
+
+    setup_proc
+    setup_devices
+
+    in_target /sbin/ldconfig
+
+    p () {
+	baseprog="$(($baseprog + ${1:-1}))"
+    }
+
+    x_feign_install () {
+        local pkg="$1"
+        local deb="$(debfor $pkg)"
+        local ver="$(
+            ar -p "$TARGET/$deb" control.tar.gz | zcat |
+                tar -O -xf - control ./control 2>/dev/null |
+                sed -ne 's/^Version: *//Ip' | head -n 1
+        )"
+
+        mkdir -p "$TARGET/var/lib/dpkg/info"
+
+        echo \
+"Package: $pkg
+Version: $ver
+Status: install ok installed" >> "$TARGET/var/lib/dpkg/status"
+
+        touch "$TARGET/var/lib/dpkg/info/${pkg}.list"
+    }
+
+    x_feign_install dpkg
+}
+
+second_stage_install () {
+    x_core_install () {
+	smallyes '' | in_target dpkg --force-depends --install $(debfor "$@")
+    }
+
+    DEBIAN_FRONTEND=noninteractive
+    export DEBIAN_FRONTEND
+
+    baseprog=0
+    bases=40
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #1
+    info INSTCORE "Installing core packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #2
+    ln -s mawk $TARGET/usr/bin/awk
+    x_core_install base-files base-passwd
+    p; progress $baseprog $bases INSTBASE "Installing base system" #3
+    x_core_install dpkg
+
+    if [ ! -e "$TARGET/etc/localtime" ]; then
+        ln -sf /usr/share/zoneinfo/UTC "$TARGET/etc/localtime"
+    fi
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #4
+    x_core_install $LIBC6
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #5
+    x_core_install perl-base
+    p; progress $baseprog $bases INSTBASE "Installing base system" #6
+    rm $TARGET/usr/bin/awk
+    x_core_install mawk
+    p; progress $baseprog $bases INSTBASE "Installing base system" #7
+
+    info UNPACKREQ "Unpacking required packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #8
+    smallyes '' | repeat 5 in_target_failmsg UNPACK_REQ_FAIL_FIVE "Failure while unpacking required packages.  This will be attempted up to five times." "" dpkg --force-depends --unpack $(debfor $required)
+    p 10; progress $baseprog $bases INSTBASE "Installing base system" #18
+
+    info CONFREQ "Configuring required packages..."
+
+    mv "$TARGET/sbin/start-stop-daemon" "$TARGET/sbin/start-stop-daemon.REAL"
+    echo \
+"#!/bin/sh
+echo
+echo \"Warning: Fake start-stop-daemon called, doing nothing\"" > "$TARGET/sbin/start-stop-daemon"
+    chmod 755 "$TARGET/sbin/start-stop-daemon"
+
+    setup_dselect_method apt
+    on_exit "in_target_nofail umount /dev/pts"
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #19
+    smallyes '' | in_target_failmsg CONF_REQ_FAIL "Failure while configuring required packages." "" dpkg --configure --pending --force-configure-any --force-depends
+    p 10; progress $baseprog $bases INSTBASE "Installing base system" #29 
+
+    info INSTBASE "Installing base packages..."
+
+    p; progress $baseprog $bases INSTBASE "Installing base system" #30
+    smallyes '' | repeat 5 in_target_failmsg INST_BASE_FAIL_FIVE "Failure while installing base packages.  This will be re-attempted up to five times." "" dpkg --force-auto-select --force-overwrite --force-confold --skip-same-version --unpack $(debfor $base)
+
+    smallyes '' | repeat 5 in_target_failmsg CONF_BASE_FAIL_FIVE "Failure while configuring base packages.  This will be attempted 5 times." "" dpkg  --force-confold --skip-same-version  --configure -a
+
+    p 9; progress $baseprog $bases INSTBASE "Installing base system" #39
+
+    mv "$TARGET/sbin/start-stop-daemon.REAL" "$TARGET/sbin/start-stop-daemon"
+
+    progress $bases $bases INSTBASE "Installing base system" #40
+    info BASESUCCESS "Base system installed successfully."
+}
